#ifndef NT2_INCLUDE_FUNCTIONS_ROL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ROL_HPP_INCLUDED

#include <nt2/bitwise/include/functions/rol.hpp>

#endif
